@@ -3,7 +3,7 @@ from __future__ import unicode_literals
 
 import functools
 import logging
-import operator
+import ntpath
 import os
 import string
 import sys
@@ -748,13 +748,10 @@ def merge_service_dicts(base, override, version):
         md.merge_field(field, merge_path_mappings)
 
     for field in [
-        'depends_on',
-        'expose',
-        'external_links',
-        'ports',
-        'volumes_from',
+        'ports', 'cap_add', 'cap_drop', 'expose', 'external_links',
+        'security_opt', 'volumes_from', 'depends_on',
     ]:
-        md.merge_field(field, operator.add, default=[])
+        md.merge_field(field, merge_unique_items_lists, default=[])
 
     for field in ['dns', 'dns_search', 'env_file', 'tmpfs']:
         md.merge_field(field, merge_list_or_string)
@@ -770,6 +767,10 @@ def merge_service_dicts(base, override, version):
     return dict(md)
 
 
+def merge_unique_items_lists(base, override):
+    return sorted(set().union(base, override))
+
+
 def merge_build(output, base, override):
     def to_dict(service):
         build_config = service.get('build', {})
@@ -939,12 +940,13 @@ def split_path_mapping(volume_path):
     path. Using splitdrive so windows absolute paths won't cause issues with
     splitting on ':'.
     """
-    # splitdrive has limitations when it comes to relative paths, so when it's
-    # relative, handle special case to set the drive to ''
-    if volume_path.startswith('.') or volume_path.startswith('~'):
+    # splitdrive is very naive, so handle special cases where we can be sure
+    # the first character is not a drive.
+    if (volume_path.startswith('.') or volume_path.startswith('~') or
+            volume_path.startswith('/')):
         drive, volume_config = '', volume_path
     else:
-        drive, volume_config = os.path.splitdrive(volume_path)
+        drive, volume_config = ntpath.splitdrive(volume_path)
 
     if ':' in volume_config:
         (host, container) = volume_config.split(':', 1)
